==> file_picker_platform_interface-0.0.1.tar.gz: lib/file_picker_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'method_channel_file_picker.dart';

enum FileType {
  any,
  media,
  image,
  video,
  audio,
  custom,
}

/// The interface that implementations of file_picker must implement.
///
/// Platform implementations should extend this class rather than implement it as `file_picker`
/// does not consider newly added methods to be breaking changes. Extending this class
/// (using `extends`) ensures that the subclass will get the default implementation, while
/// platform implementations that `implements` this interface will be broken by newly added
/// [FilePickerPlatform] methods.
abstract class FilePickerPlatform extends PlatformInterface {
  /// Constructs a UrlLauncherPlatform.
  FilePickerPlatform() : super(token: _token);

  static final Object _token = Object();

  static FilePickerPlatform _instance = MethodChannelFilePicker();

  static FilePickerPlatform get instance => _instance;

  static set instance(FilePickerPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<Map<String, String>> getMultiFilePath({FileType type = FileType.any, List<String> allowedExtensions}) async =>
      throw UnimplementedError('getMultiFilePath() has not been implemented.');

  /// Returns an absolute file path from the calling platform.
  ///
  /// Extension filters are allowed with `FileType.custom`, when used, make sure to provide a `List`
  /// of [allowedExtensions] (e.g. [`pdf`, `svg`, `jpg`].).
  /// Defaults to `FileType.any` which will display all file types.
  Future<String> getFilePath({FileType type = FileType.any, List<String> allowedExtensions}) async =>
      throw UnimplementedError('getFilePath() has not been implemented.');

  /// Returns a `File` object from the selected file path.
  ///
  /// This is an utility method that does the same of `getFilePath()` but saving some boilerplate if
  /// you are planing to create a `File` for the returned path.
  Future<dynamic> getFile({FileType type = FileType.any, List<String> allowedExtensions}) async =>
      throw UnimplementedError('getFile() has not been implemented.');

  /// Asks the underlying platform to remove any temporary files created by this plugin.
  ///
  /// This typically relates to cached files that are stored in the cache directory of
  /// each platform and it isn't required to invoke this as the system should take care
  /// of it whenever needed. However, this will force the cleanup if you want to manage those on your own.
  ///
  /// Returns `true` if the files were removed with success, `false` otherwise.
  Future<bool> clearTemporaryFiles() async => throw UnimplementedError('clearTemporaryFiles() has not been implemented.');

  /// Returns a `List<File>` object from the selected files paths.
  ///
  /// This is an utility method that does the same of `getMultiFilePath()` but saving some boilerplate if
  /// you are planing to create a list of `File`s for the returned paths.
  Future<List<dynamic>> getMultiFile({FileType type = FileType.any, List<String> allowedExtensions}) async =>
      throw UnimplementedError('getMultiFile() has not been implemented.');
}

==> file_picker_platform_interface-0.0.2.tar.gz: lib/file_picker_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'method_channel_file_picker.dart';

enum FileType {
  any,
  media,
  image,
  video,
  audio,
  custom,
}

/// The interface that implementations of file_picker must implement.
///
/// Platform implementations should extend this class rather than implement it as `file_picker`
/// does not consider newly added methods to be breaking changes. Extending this class
/// (using `extends`) ensures that the subclass will get the default implementation, while
/// platform implementations that `implements` this interface will be broken by newly added
/// [FilePickerPlatform] methods.
abstract class FilePickerPlatform extends PlatformInterface {
  /// Constructs a UrlLauncherPlatform.
  FilePickerPlatform() : super(token: _token);

  static final Object _token = Object();

  static FilePickerPlatform _instance = MethodChannelFilePicker();

  static FilePickerPlatform get instance => _instance;

  static set instance(FilePickerPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<dynamic> getFilePath({FileType type = FileType.any, List<String> allowedExtensions, bool allowMultiple = false}) async =>
      throw UnimplementedError('getMultiFilePath() has not been implemented.');

  Future<dynamic> getFile({FileType type = FileType.any, List<String> allowedExtensions, bool allowMultiple = false}) async =>
      throw UnimplementedError('getMultiFile() has not been implemented.');

  Future<bool> clearTemporaryFiles() async => throw UnimplementedError('clearTemporaryFiles() has not been implemented.');
}
